import websocket
from base64 import b64encode as enc


class Sinric:
    def __init__(self, apikey):
        self.apikey = apikey.encode('ascii')

    def initialize(self):
        websocket.enableTrace(True)
        ws = websocket.create_connection('ws://iot.sinric.com',
                                         header={'Authorization:' + enc(b'apikey:'+self.apikey).decode('ascii')})
        response = ws.recv()
        ws.close()
        return response



from setuptools import setup

VERSION = "0.0.4"

with open('README.rst', 'r') as f:
    long_description = f.read()
setup(
    name="pysinric",
    version=VERSION,
    author="dazzHere",
    author_email="dhanushdazz@gmail.com",
    description="A python package for your sinric alexa skill",
    long_description=long_description,
    url="https://github.com/kakopappa/sinric",
    packages=['sinric'],
    install_requires=['websocket_client'],
    keywords=['alexa', 'alexa-skill', 'sinric', 'sinric-alexa-skill', 'alexa-home-automation'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 2",
        "Operating System :: OS Independent",
    ]
)
